@@ -1,5 +1,5 @@
 use crate::id::Id;
-use fxhash::FxHashMap;
+use rustc_hash::FxHashMap;
 use swc_atoms::js_word;
 use swc_common::util::take::Take;
 use swc_ecma_ast::*;
